"""standardize notification naming

Revision ID: 6238230adb52
Revises: 104070a25743
Create Date: 2023-01-03 10:51:29.899515

"""
from alembic import op


# revision identifiers, used by Alembic.
revision = "6238230adb52"
down_revision = "104070a25743"
branch_labels = None
depends_on = None

names = [
    "workflow-submitted",
    "workflow-complete",
    "workflow-failed",
]


old_ingest_failed = """To: {{destination_email}}{{#cc_email}}
Cc: {{cc_email}}{{/cc_email}}
Subject: NRAO Workspaces - Ingestion failed for request #{{version.capability.request_id}}


Dear DA,

A {{version.capability_name}} request #{{version.capability_request_id}} failed to be ingested into the archive.

Best regards,
NRAO Workspaces
"""

old_qa_ready = """To: {{destination_email}}{{#cc_email}}
Cc: {{cc_email}}{{/cc_email}}
Subject: NRAO Workspaces Request #{{version.capability_request_id}}: Ready for QA


Dear DA,

A {{version.capability_name}} request is ready for QA.

You can review the weblog, add notes, and decide the QA status here:

{{version.request.status_url}}

Best regards,

NRAO Workspaces
"""


def upgrade():

    op.execute(
        """
        DELETE FROM notification_templates
        WHERE name IN ('ready-for-QA_email', 'ingestion_failed_email')
        """
    )

    for template in names:
        op.execute(
            f"""
            UPDATE notification_templates
            SET name='{template.replace('-','_')}'
            WHERE name='{template}'
            """
        )


def downgrade():
    for template in names:
        op.execute(
            f"""
            UPDATE notification_templates
            SET name='{template}'
            WHERE name='{template.replace('_','-')}'
            """
        )

    op.execute(
        f"""
        INSERT INTO archive.public.notification_templates (name, description, template) 
        VALUES ('ready-for-QA_email', 'An email template for notifying a DA that a capability request is ready for QA.', '{old_qa_ready}') 
        """
    )
    op.execute(
        f"""
        INSERT INTO archive.public.notification_templates (name, description, template) 
        VALUES ('ingestion_failed_email', 'An email template for notifying the DA list that an ingestion has failed', '{old_ingest_failed}') 
        """
    )
