# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""incorporate QA into std_calibration state machine

Revision ID: acfdeb6777cb
Revises: 8ad5f0630fc0
Create Date: 2021-11-09 10:06:10.915761

"""
from alembic import op

# revision identifiers, used by Alembic.
revision = "acfdeb6777cb"
down_revision = "8ad5f0630fc0"
branch_labels = None
depends_on = None


def upgrade():
    """
    Change transition [Executing] -(workflow-complete)-> [Complete] TO [Executing] -(workflow-complete)-> [Awaiting QA]
    AND
    Add action for that transition: SendMessage qa_ready
    """

    op.execute(
        """
        UPDATE capability_state_transitions SET to_state = 'Awaiting QA'
        WHERE from_state = 'Executing' AND pattern = 'type == workflow-complete'
        AND capability_name = 'std_calibration';

        INSERT INTO capability_state_actions (transition_id, action_type, arguments)
        SELECT transition_id, 'SendMessage', 'qa_ready' AS arguments
        FROM capability_state_transitions WHERE pattern = 'type == workflow-complete'
        AND capability_name = 'std_calibration';
        """
    )


def downgrade():

    op.execute(
        """
        UPDATE capability_state_transitions SET to_state = 'Complete'
        WHERE from_state = 'Executing' AND pattern = 'type == workflow-complete' AND capability_name = 'std_calibration';

        DELETE FROM capability_state_actions WHERE action_type = 'SendMessage'
        AND arguments = 'qa_ready'
        AND transition_id = (
            SELECT transition_id FROM capability_state_transitions
            WHERE pattern = 'type == workflow-complete' AND capability_name = 'std_calibration'
        );
        """
    )
